/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Path } from '@athenna/common';
import { BaseCommand, Argument, Option } from '@athenna/artisan';
export class MakeTestCommand extends BaseCommand {
    static signature() {
        return 'make:test';
    }
    static description() {
        return 'Make a new test file.';
    }
    async handle() {
        this.logger.simple('({bold,green} [ MAKING TEST ])\n');
        let template = 'test';
        if (this.isConsole)
            template = 'test-console';
        else if (this.isHttp)
            template = 'test-http';
        else if (this.isUnit)
            template = 'test'; // This is necessary to avoid multiple options case.
        if (this.isFunction) {
            template = 'test-fn';
        }
        const destination = Config.get('rc.commands.make:test.destination', this.isUnit ? Path.tests('unit') : Path.tests('e2e'));
        const file = await this.generator
            .fileName(this.name)
            .destination(destination)
            .template(template)
            .setNameProperties(true)
            .make();
        this.logger.success(`Test ({yellow} "${file.name}") successfully created.`);
    }
}
__decorate([
    Argument({
        description: 'The test name.'
    }),
    __metadata("design:type", String)
], MakeTestCommand.prototype, "name", void 0);
__decorate([
    Option({
        description: 'Create an unitary test.',
        signature: '-u, --unit',
        default: false
    }),
    __metadata("design:type", Boolean)
], MakeTestCommand.prototype, "isUnit", void 0);
__decorate([
    Option({
        description: 'Create a HTTP test.',
        signature: '-h, --http',
        default: false
    }),
    __metadata("design:type", Boolean)
], MakeTestCommand.prototype, "isHttp", void 0);
__decorate([
    Option({
        description: 'Create a Console test.',
        signature: '-c, --console',
        default: false
    }),
    __metadata("design:type", Boolean)
], MakeTestCommand.prototype, "isConsole", void 0);
__decorate([
    Option({
        description: 'Create the test as function instead of class.',
        signature: '--function',
        default: false
    }),
    __metadata("design:type", Boolean)
], MakeTestCommand.prototype, "isFunction", void 0);
